@@ -2,7 +2,6 @@ import logging
 from datetime import datetime
 from datetime import timezone
 from typing import List
-from typing import Union
 
 import cryptocompare
 from senor_octopus.types import Stream
@@ -11,14 +10,31 @@ _logger = logging.getLogger(__name__)
 
 
 async def crypto(
-    coins: Union[str, List[str]],
+    coins: List[str],
     currency: str = "USD",
     prefix: str = "hub.crypto",
 ) -> Stream:
-    _logger.info("Fetching crypto data")
+    """
+    Fetch price of cryptocurrencies from cryptocompare.com.
 
-    if isinstance(coins, str):
-        coins = [coin.strip() for coin in coins.split(",")]
+    This source will periodically retrieve the price of
+    cryptocurrencies from the cryptocompare.com website.
+
+    Parameters
+    ----------
+    coins
+        List of cryptocurrency symbols
+    currency
+        Currency used to display price
+    prefix
+        Prefix for events from this source
+
+    Yields
+    ------
+    Event
+        Events with price of cryptocurrencies
+    """
+    _logger.info("Fetching crypto data")
 
     for coin in coins:
         info = cryptocompare.get_price(coin, currency=currency, full=False)
