@@ -16,12 +16,12 @@ def test_parse_args() -> None:
         parse_args(["--version"])
     assert str(excinfo.value) == "0"
 
-    parser = parse_args(["config.ini", "-vv"])
-    assert parser.f == "config.ini"
+    parser = parse_args(["config.yaml", "-vv"])
+    assert parser.f == "config.yaml"
     assert parser.loglevel == logging.DEBUG
 
-    parser = parse_args(["config.ini", "-v"])
-    assert parser.f == "config.ini"
+    parser = parse_args(["config.yaml", "-v"])
+    assert parser.f == "config.yaml"
     assert parser.loglevel == logging.INFO
 
 
@@ -41,29 +41,31 @@ def test_setup_logging(mocker, capfd) -> None:
 
 @pytest.mark.asyncio
 async def test_main(mocker) -> None:
-    mocker.patch("senor_octopus.cli.CaseConfigParser")
+    mocker.patch("senor_octopus.cli.yaml")
     mocker.patch("senor_octopus.cli.build_dag")
+    mocker.patch("senor_octopus.cli.open")
 
     mock_scheduler = mock.MagicMock()
     mock_scheduler.return_value.run = CoroutineMock()
     mocker.patch("senor_octopus.cli.Scheduler", mock_scheduler)
 
-    await main(["config.ini"])
+    await main(["config.yaml"])
 
     mock_scheduler.return_value.run.assert_called()
 
 
 @pytest.mark.asyncio
 async def test_main_canceled(mocker) -> None:
-    mocker.patch("senor_octopus.cli.CaseConfigParser")
+    mocker.patch("senor_octopus.cli.yaml")
     mocker.patch("senor_octopus.cli.build_dag")
+    mocker.patch("senor_octopus.cli.open")
 
     mock_scheduler = mock.MagicMock()
     mock_scheduler.return_value.run = CoroutineMock()
     mock_scheduler.return_value.run.side_effect = asyncio.CancelledError("Canceled")
     mocker.patch("senor_octopus.cli.Scheduler", mock_scheduler)
 
-    await main(["config.ini"])
+    await main(["config.yaml"])
 
     mock_scheduler.return_value.cancel.assert_called()
 
@@ -71,21 +73,20 @@ async def test_main_canceled(mocker) -> None:
 def test_run(mocker) -> None:
     mock_main = CoroutineMock()
     mocker.patch("senor_octopus.cli.main", mock_main)
-    mocker.patch("senor_octopus.cli.sys.argv", ["srocto", "config.ini", "-vv"])
+    mocker.patch("senor_octopus.cli.sys.argv", ["srocto", "config.yaml", "-vv"])
 
     run()
 
-    mock_main.assert_called_with(["config.ini", "-vv"])
+    mock_main.assert_called_with(["config.yaml", "-vv"])
 
 
 def test_interrupt(mocker) -> None:
     mock_main = CoroutineMock()
     mock_main.side_effect = KeyboardInterrupt()
     mocker.patch("senor_octopus.cli.main", mock_main)
-    mocker.patch("senor_octopus.cli.sys.argv", ["srocto", "config.ini", "-vv"])
-    mock_logger = mocker.MagicMock()
-    mocker.patch("senor_octopus.cli._logger", mock_logger)
+    mocker.patch("senor_octopus.cli.sys.argv", ["srocto", "config.yaml", "-vv"])
+    mock_logger = mocker.patch("senor_octopus.cli._logger")
 
     run()
 
-    assert mock_logger.info.called_with("Stopping Sr. Octopus")
+    mock_logger.info.assert_called_with("Stopping Sr. Octopus")
