@@ -1,12 +1,11 @@
 import asyncio
 import random
 from typing import cast
-from typing import Dict
 
 import aiotools
 import pytest
+import yaml
 from freezegun import freeze_time
-from senor_octopus.cli import CaseConfigParser
 from senor_octopus.graph import build_dag
 from senor_octopus.graph import connected
 from senor_octopus.graph import Sink
@@ -57,20 +56,19 @@ async def test_build_dag(mock_config) -> None:
 
 @pytest.mark.asyncio
 async def test_build_dag_many_to_one() -> None:
-    config = CaseConfigParser()
-    config.read_string(
+    config = yaml.load(
         """
-        [one]
-        plugin = source.random
-        flow = -> three
+one:
+  plugin: source.random
+  flow: -> three
 
-        [two]
-        plugin = source.random
-        flow = -> three
+two:
+  plugin: source.random
+  flow: -> three
 
-        [three]
-        plugin = sink.log
-        flow = * ->
+three:
+  plugin: sink.log
+  flow: "* ->"
     """,
     )
     dag = build_dag(config)
@@ -81,11 +79,10 @@ async def test_build_dag_many_to_one() -> None:
 
 
 def test_build_dag_missing_plugin() -> None:
-    config = CaseConfigParser()
-    config.read_string(
+    config = yaml.load(
         """
-        [a]
-        flow = -> *
+a:
+  flow: -> *
     """,
     )
     with pytest.raises(Exception) as excinfo:
@@ -95,31 +92,29 @@ def test_build_dag_missing_plugin() -> None:
 
 @pytest.mark.asyncio
 async def test_build_dag_seen() -> None:
-    config = CaseConfigParser()
-    config.read_string(
+    config = yaml.load(
         """
-        [a]
-        flow = -> *
-        plugin = source.random
+a:
+  flow: -> *
+  plugin: source.random
 
-        [b]
-        flow = -> *
-        plugin = source.random
+b:
+  flow: -> *
+  plugin: source.random
 
-        [c]
-        flow = * ->
-        plugin = sink.log
+c:
+  flow: "* ->"
+  plugin: sink.log
     """,
     )
     build_dag(config)
 
 
 def test_build_dag_missing_flow() -> None:
-    config = CaseConfigParser()
-    config.read_string(
+    config = yaml.load(
         """
-        [a]
-        plugin = source.random
+a:
+  plugin: source.random
     """,
     )
     with pytest.raises(Exception) as excinfo:
@@ -128,12 +123,11 @@ def test_build_dag_missing_flow() -> None:
 
 
 def test_build_dag_invalid_plugin() -> None:
-    config = CaseConfigParser()
-    config.read_string(
+    config = yaml.load(
         """
-        [a]
-        plugin = source.invalid
-        flow = -> *
+a:
+  plugin: source.invalid
+  flow: -> *
     """,
     )
     with pytest.raises(Exception) as excinfo:
@@ -141,28 +135,10 @@ def test_build_dag_invalid_plugin() -> None:
     assert str(excinfo.value) == "Invalid plugin name `source.invalid`"
 
 
-def test_build_dag_environ(mocker) -> None:
-    mock_env: Dict[str, str] = {}
-    mocker.patch("senor_octopus.graph.os.environ", mock_env)
-
-    config = CaseConfigParser()
-    config.read_string(
-        """
-        [a]
-        flow = -> *
-        plugin = source.random
-        A_ENV_VAR = 1
-    """,
-    )
-    build_dag(config)
-    assert mock_env == {"A_ENV_VAR": "1"}
-
-
 @freeze_time("2021-01-01")
 @pytest.mark.asyncio
 async def test_run_source(mocker, mock_config) -> None:
-    mock_logger = mocker.MagicMock()
-    mocker.patch("senor_octopus.sinks.log._logger", mock_logger)
+    mock_logger = mocker.patch("senor_octopus.sinks.log._logger")
     random.seed(42)
 
     dag = build_dag(mock_config)
@@ -178,23 +154,22 @@ async def test_run_source(mocker, mock_config) -> None:
 
 @pytest.mark.asyncio
 async def test_batch(mocker) -> None:
-    mock_logger = mocker.MagicMock()
-    mocker.patch("senor_octopus.sinks.log._logger", mock_logger)
+    mock_logger = mocker.patch("senor_octopus.sinks.log._logger")
     vclock = aiotools.VirtualClock()
 
-    config_content = """
-[random]
-plugin = source.random
-flow = -> log
-schedule = * * * * *
+    config = yaml.load(
+        """
+random:
+  plugin: source.random
+  flow: -> log
+  schedule: "* * * * *"
 
-[log]
-plugin = sink.log
-flow = random ->
-batch = 2 minutes
-    """
-    config = CaseConfigParser()
-    config.read_string(config_content)
+log:
+  plugin: sink.log
+  flow: random ->
+  batch: 2 minutes
+    """,
+    )
 
     with vclock.patch_loop():
         dag = build_dag(config)
@@ -209,24 +184,23 @@ batch = 2 minutes
 
 @pytest.mark.asyncio
 async def test_batch_empty_source(mocker) -> None:
-    mock_logger = mocker.MagicMock()
-    mocker.patch("senor_octopus.sinks.log._logger", mock_logger)
+    mock_logger = mocker.patch("senor_octopus.sinks.log._logger")
     vclock = aiotools.VirtualClock()
 
-    config_content = """
-[random]
-plugin = source.random
-flow = -> log
-schedule = * * * * *
-events = 0
+    config = yaml.load(
+        """
+random:
+  plugin: source.random
+  flow: -> log
+  schedule: "* * * * *"
+  events: 0
 
-[log]
-plugin = sink.log
-flow = random ->
-batch = 2 minutes
-    """
-    config = CaseConfigParser()
-    config.read_string(config_content)
+log:
+  plugin: sink.log
+  flow: random ->
+  batch: 2 minutes
+    """,
+    )
 
     with vclock.patch_loop():
         dag = build_dag(config)
@@ -239,26 +213,102 @@ batch = 2 minutes
         assert len(mock_logger.log.mock_calls) == 0
 
 
+@pytest.mark.asyncio
+async def test_throttle(mocker) -> None:
+    _logger = mocker.patch("senor_octopus.sinks.log._logger")
+    vclock = aiotools.VirtualClock()
+
+    config = yaml.load(
+        """
+random:
+  plugin: source.random
+  flow: -> log
+  schedule: "* * * * *"
+  events: 1
+
+log:
+  plugin: sink.log
+  flow: random ->
+  throttle: 2 minutes
+    """,
+    )
+
+    with vclock.patch_loop():
+        dag = build_dag(config)
+        source = dag.pop()
+        sink = list(source.next)[0]
+
+        sink = cast(Sink, sink)
+        assert sink.last_run is None
+
+        await source.run()
+        assert len(_logger.log.mock_calls) == 1
+        assert sink.last_run == 0.0
+
+        await asyncio.sleep(60)
+        await source.run()
+        assert len(_logger.log.mock_calls) == 1
+        assert sink.last_run == 0.0
+
+        await asyncio.sleep(150)
+        await source.run()
+        assert len(_logger.log.mock_calls) == 2
+        assert sink.last_run == 210.0
+
+
+@pytest.mark.asyncio
+async def test_throttle_without_events(mocker) -> None:
+    _logger = mocker.patch("senor_octopus.sinks.log._logger")
+    vclock = aiotools.VirtualClock()
+
+    config = yaml.load(
+        """
+random:
+  plugin: source.random
+  flow: -> log
+  schedule: "* * * * *"
+  events: 0
+
+log:
+  plugin: sink.log
+  flow: random ->
+  throttle: 2 minutes
+    """,
+    )
+
+    with vclock.patch_loop():
+        dag = build_dag(config)
+        source = dag.pop()
+        sink = list(source.next)[0]
+
+        sink = cast(Sink, sink)
+        assert sink.last_run is None
+
+        await source.run()
+        assert len(_logger.log.mock_calls) == 0
+        assert sink.last_run is None
+
+
 @pytest.mark.asyncio
 async def test_batch_cancel(mocker) -> None:
     mock_logger = mocker.MagicMock()
     mocker.patch("senor_octopus.sinks.log._logger", mock_logger)
     vclock = aiotools.VirtualClock()
 
-    config_content = """
-[random]
-plugin = source.random
-flow = -> log
-schedule = * * * * *
-events = 0
+    config = yaml.load(
+        """
+random:
+  plugin: source.random
+  flow: -> log
+  schedule: "* * * * *"
+  events: 0
 
-[log]
-plugin = sink.log
-flow = random ->
-batch = 2 minutes
-    """
-    config = CaseConfigParser()
-    config.read_string(config_content)
+log:
+  plugin: sink.log
+  flow: random ->
+  batch: 2 minutes
+    """,
+    )
 
     with vclock.patch_loop():
         dag = build_dag(config)
